======
nidaba
======

`nidaba` is an open source distributed optical character recognition pipeline
that makes it easy to preprocess and OCR scans of text documents in a multitude
of ways.

`nidaba` is a powerful tool allowing you to mix and combine some of the most
advanced free image processing and character recognition software and
distribute the execution of this software to multiple machines. While the
learning curve may be high at first, you'll be able in no time to process your
own scanned documents.

What It Does
============

nidaba does a bunch of things for you:

        * **Grayscale Conversion**
        * **Binarization**
        * **Deskewing**
        * **Dewarping**
        * **OCR**
        * **Output merging**


.. toctree::
   :maxdepth: 2

   user-guide/index
   tech-reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
